function [mod_rf,i_scale,o_scale] = load_gzwd_rf_mod_paras(mod_opt)
%
% This subroutine is used to load model parameters for calculating zenith
% wet delays based on the RF-based GZWD_RF model. It must be placed ahead 
% of the for loop, which runs through all observations in order to avoid 
% time-consuming problem. 
%
% input parameters:
% mod_opt           I   model type (1: gzwd_rf_a; 2: gzwd_rf_b; 3: gzwd_rf_c)
% 
% output parameters:
% mod_rf            O   RF-based model coefficients
% i_scale           O   scales for the normalization of the input parameters, class
% o_scale       	O   scales for the normalization of the output parameters, class
%
% (c) Faculty of Geosciences and Environmental Engineering, Southwest
% Jiaotong University, 611756, P.R.China
% (c) Department of Higher Geodesy, Vienna University of Techonology (TU Wien),
% Wien 1040, Austria
%
% Qinzheng Li
% version 1, January 1, 2022
% version 2, July 20, 2022, (Global ZWD modeling based on the combination of 
% radiosonde measurements and GPS radio occultations)

switch (mod_opt)
    case (1)
        load(['gzwd_rf_A.mat'],'ipara_scale','opara_scale','model_rf');
        i_scale = ipara_scale; o_scale = opara_scale;
        mod_rf = model_rf;
        clear ipara_scale opara_scale model_rf;
    case (2)
        load(['gzwd_rf_B.mat'],'ipara_scale','opara_scale','model_rf');
        i_scale = ipara_scale; o_scale = opara_scale;
        mod_rf = model_rf;
        clear ipara_scale opara_scale model_rf;
    case {3}
        load(['gzwd_rf_C.mat'],'ipara_scale','opara_scale','model_rf');
        i_scale = ipara_scale; o_scale = opara_scale;
        mod_rf = model_rf;
        clear ipara_scale opara_scale model_rf;
    case {4}
        load(['gzwd_rf_D.mat'],'ipara_scale','opara_scale','model_rf');
        i_scale = ipara_scale; o_scale = opara_scale;
        mod_rf = model_rf;
        clear ipara_scale opara_scale model_rf;
end

end
